==> robovm-cocoatouch-1.8.0-sources.jar: org/robovm/apple/foundation/NSURLRequestNetworkServiceType.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.foundation;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.corefoundation.*;
import org.robovm.apple.uikit.*;
import org.robovm.apple.coretext.*;
import org.robovm.apple.coreanimation.*;
import org.robovm.apple.coredata.*;
import org.robovm.apple.coregraphics.*;
import org.robovm.apple.coremedia.*;
import org.robovm.apple.security.*;
import org.robovm.apple.dispatch.*;
/*</imports>*/

/*<javadoc>*/

/*</javadoc>*/
/*<annotations>*/@Marshaler(ValuedEnum.AsMachineSizedUIntMarshaler.class)/*</annotations>*/
public enum /*<name>*/NSURLRequestNetworkServiceType/*</name>*/ implements ValuedEnum {
    /*<values>*/
    Default(0L),
    VoIP(1L),
    Video(2L),
    Background(3L),
    Voice(4L);
    /*</values>*/

    private final long n;

    private /*<name>*/NSURLRequestNetworkServiceType/*</name>*/(long n) { this.n = n; }
    public long value() { return n; }
    public static /*<name>*/NSURLRequestNetworkServiceType/*</name>*/ valueOf(long n) {
        for (/*<name>*/NSURLRequestNetworkServiceType/*</name>*/ v : values()) {
            if (v.n == n) {
                return v;
            }
        }
        throw new IllegalArgumentException("No constant with value " + n + " found in " 
            + /*<name>*/NSURLRequestNetworkServiceType/*</name>*/.class.getName());
    }
}

==> robovm-cocoatouch-2.3.18-sources.jar: org/robovm/apple/foundation/NSURLRequestNetworkServiceType.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.foundation;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.corefoundation.*;
import org.robovm.apple.uikit.*;
import org.robovm.apple.coretext.*;
import org.robovm.apple.coreanimation.*;
import org.robovm.apple.coredata.*;
import org.robovm.apple.coregraphics.*;
import org.robovm.apple.coremedia.*;
import org.robovm.apple.security.*;
import org.robovm.apple.dispatch.*;
/*</imports>*/

/*<javadoc>*/

/*</javadoc>*/
/*<annotations>*/@Marshaler(ValuedEnum.AsMachineSizedUIntMarshaler.class)/*</annotations>*/
public enum /*<name>*/NSURLRequestNetworkServiceType/*</name>*/ implements ValuedEnum {
    /*<values>*/
    Default(0L),
    /**
     * @deprecated Deprecated in iOS 13.0. Use PushKit for VoIP control purposes
     */
    @Deprecated
    VoIP(1L),
    Video(2L),
    Background(3L),
    Voice(4L),
    ResponsiveData(6L),
    AVStreaming(8L),
    ResponsiveAV(9L),
    /**
     * @since Available in iOS 10.0 and later.
     */
    CallSignaling(11L);
    /*</values>*/

    private final long n;

    private /*<name>*/NSURLRequestNetworkServiceType/*</name>*/(long n) { this.n = n; }
    public long value() { return n; }
    public static /*<name>*/NSURLRequestNetworkServiceType/*</name>*/ valueOf(long n) {
        for (/*<name>*/NSURLRequestNetworkServiceType/*</name>*/ v : values()) {
            if (v.n == n) {
                return v;
            }
        }
        throw new IllegalArgumentException("No constant with value " + n + " found in " 
            + /*<name>*/NSURLRequestNetworkServiceType/*</name>*/.class.getName());
    }
}
